==> haskell-attoparsec-iso8601-1.1.1.0-19.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-attoparsec-iso8601.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 attoparsec-iso8601
version:              1.1.1.0
visibility:           public
id:                   attoparsec-iso8601-1.1.1.0-ADVkhdQiZoY1ANNOHw0II0
key:                  attoparsec-iso8601-1.1.1.0-ADVkhdQiZoY1ANNOHw0II0
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/haskell/aeson
synopsis:             Parsing of ISO 8601 dates, originally from aeson
description:          Parsing of ISO 8601 dates, originally from aeson.
category:             Parsing
abi:                  597ef6a2ccd78d7d4876d84f8959e22c
exposed:              True
exposed-modules:      Data.Attoparsec.Time Data.Attoparsec.Time.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/attoparsec-iso8601-1.1.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/attoparsec-iso8601-1.1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/attoparsec-iso8601-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec-iso8601
hs-libraries:         HSattoparsec-iso8601-1.1.1.0-ADVkhdQiZoY1ANNOHw0II0
depends:
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    integer-conversion-0.1.1-DRB3SWHoRBCJxKDeuc2gjJ text-2.0.2
    time-1.12.2 time-compat-1.9.8-KXBZmSgVcbpGOqrx2hUfcV

haddock-interfaces:
    /usr/share/doc/haskell-attoparsec-iso8601/html/attoparsec-iso8601.haddock

haddock-html:         /usr/share/doc/haskell-attoparsec-iso8601/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-attoparsec-iso8601-1.1.1.0-20-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-attoparsec-iso8601.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 attoparsec-iso8601
version:              1.1.1.0
visibility:           public
id:                   attoparsec-iso8601-1.1.1.0-3GfC7FWyDNaItselModcsw
key:                  attoparsec-iso8601-1.1.1.0-3GfC7FWyDNaItselModcsw
license:              BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:           Adam Bergmark <adam@bergmark.nl>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
stability:            experimental
homepage:             https://github.com/haskell/aeson
synopsis:             Parsing of ISO 8601 dates, originally from aeson
description:          Parsing of ISO 8601 dates, originally from aeson.
category:             Parsing
abi:                  cdd982aab2cc13a13274c74f3c65d63b
exposed:              True
exposed-modules:      Data.Attoparsec.Time Data.Attoparsec.Time.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/attoparsec-iso8601-1.1.1.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/attoparsec-iso8601-1.1.1.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/attoparsec-iso8601-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-attoparsec-iso8601
hs-libraries:         HSattoparsec-iso8601-1.1.1.0-3GfC7FWyDNaItselModcsw
depends:
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    integer-conversion-0.1.1-1JOh3kEXs2A1lWf7CGpMKt text-2.0.2
    time-1.12.2 time-compat-1.9.8-ITy6Cf33IaSAWRM66COV33

haddock-interfaces:
    /usr/share/doc/haskell-attoparsec-iso8601/html/attoparsec-iso8601.haddock

haddock-html:         /usr/share/doc/haskell-attoparsec-iso8601/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
